@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 // Qt includes
 #include <QDebug>
@@ -65,11 +51,7 @@ class KNSBackendFactory : public AbstractResourcesBackendFactory {
         QVector<AbstractResourcesBackend*> newInstance(QObject* parent, const QString &/*name*/) const override
         {
             QVector<AbstractResourcesBackend*> ret;
-#if KNEWSTUFFCORE_VERSION_MAJOR==5 && KNEWSTUFFCORE_VERSION_MINOR>=57
-            QStringList locations = KNSCore::Engine::configSearchLocations();
-#else
-            QStringList locations = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
-#endif
+            const QStringList locations = KNSCore::Engine::configSearchLocations();
             QSet<QString> files;
             for (const QString &path: locations) {
                 QDirIterator dirIt(path, {QStringLiteral("*.knsrc")}, QDir::Files);
@@ -154,9 +136,9 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
     }
 
     QVector<Category*> topCategories{categories};
-    for (const auto &cat: categories) {
+    for (const auto &cat: qAsConst(categories)) {
         const QString catName = cat->name().append(QLatin1Char('/'));
-        for (const auto& potentialSubCat: categories) {
+        for (const auto& potentialSubCat: qAsConst(categories)) {
             if(potentialSubCat->name().startsWith(catName)) {
                 cat->addSubcategory(potentialSubCat);
                 topCategories.removeOne(potentialSubCat);
@@ -170,10 +152,10 @@ KNSBackend::KNSBackend(QObject* parent, const QString& iconName, const QString &
     connect(m_engine, &KNSCore::Engine::signalEntryChanged, this, &KNSBackend::statusChanged, Qt::QueuedConnection);
     connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, this, &KNSBackend::detailsLoaded);
     connect(m_engine, &KNSCore::Engine::signalProvidersLoaded, this, &KNSBackend::fetchInstalled);
-    connect(m_engine, &KNSCore::Engine::signalCategoriesMetadataLoded, this, [categories](const QList< KNSCore::Provider::CategoryMetadata>& categoryMetadatas){
+    connect(m_engine, &KNSCore::Engine::signalCategoriesMetadataLoded, this, [categories] (const QList<KNSCore::Provider::CategoryMetadata>& categoryMetadatas){
         for (const KNSCore::Provider::CategoryMetadata& category : categoryMetadatas) {
-            for (Category* cat : categories) {
-                if (cat->orFilters().count() > 0 && cat->orFilters().first().second == category.name) {
+            for (Category* cat : qAsConst(categories)) {
+                if (cat->orFilters().count() > 0 && cat->orFilters().constFirst().second == category.name) {
                     cat->setName(category.displayName);
                     break;
                 }
@@ -242,10 +224,22 @@ void KNSBackend::markInvalid(const QString &message)
 void KNSBackend::fetchInstalled()
 {
     auto search = new OneTimeAction([this]() {
+        // First we ensure we've got data loaded on what we've got installed already
         Q_EMIT startingSearch();
         m_onePage = true;
         m_responsePending = true;
         m_engine->checkForInstalled();
+        // And then we check for updates - we could do only one, if all we cared about was updates,
+        // but to have both a useful initial list, /and/ information on updates, we want to get both.
+        // The reason we are not doing a checkUpdates() overload for this is that the caching for this
+        // information is done by KNSEngine, and we want to actually load it every time we initialize.
+        auto updateChecker = new OneTimeAction([this]() {
+            Q_EMIT startingSearch();
+            m_onePage = true;
+            m_responsePending = true;
+            m_engine->checkForUpdates();
+        }, this);
+        connect(this, &KNSBackend::availableForQueries, updateChecker, &OneTimeAction::trigger, Qt::QueuedConnection);
     }, this);
 
     if (m_responsePending) {
@@ -255,6 +249,26 @@ void KNSBackend::fetchInstalled()
     }
 }
 
+void KNSBackend::checkForUpdates()
+{
+    // Since we load the updates during initialization already, don't overburden
+    // the machine with multiple of these, because that would just be silly.
+    if (m_initialized) {
+        auto updateChecker = new OneTimeAction([this]() {
+            Q_EMIT startingSearch();
+            m_onePage = true;
+            m_responsePending = true;
+            m_engine->checkForUpdates();
+        }, this);
+
+        if (m_responsePending) {
+            connect(this, &KNSBackend::availableForQueries, updateChecker, &OneTimeAction::trigger, Qt::QueuedConnection);
+        } else {
+            updateChecker->trigger();
+        }
+    }
+}
+
 void KNSBackend::setFetching(bool f)
 {
     if(m_fetching!=f) {
@@ -409,15 +423,17 @@ public:
             actionFunction = [res, engine]() {
                 engine->uninstall(res->entry());
             };
-        else if (res->linkIds().isEmpty())
+        else if (res->entry().status() == KNS3::Entry::Updateable)
             actionFunction = [res, engine]() {
-                engine->install(res->entry());
+                engine->install(res->entry(), -1);
+            };
+        else if (res->linkIds().isEmpty())
+            actionFunction = [res]() {
+                qWarning() << "No installable candidates in the KNewStuff entry" << res->entry().name() << "with id" << res->entry().uniqueId() << "on the backend" << res->backend()->name() << "There should always be at least one downloadable item in an OCS entry, and if there isn't, we should consider it broken. OCS can technically show them, but if there is nothing to install, it cannot be installed.";
             };
         else
             actionFunction = [res, engine]() {
-                const auto links = res->linkIds();
-                for(auto i : links)
-                    engine->install(res->entry(), i);
+                engine->install(res->entry());
             };
         QTimer::singleShot(0, res, actionFunction);
     }
@@ -609,7 +625,7 @@ QString KNSBackend::displayName() const
 void KNSBackend::detailsLoaded(const KNSCore::EntryInternal& entry)
 {
     auto res = resourceForEntry(entry);
-    res->longDescriptionChanged();
+    Q_EMIT res->longDescriptionChanged();
 }
 
 #include "KNSBackend.moc"
